==> dhall-json-1.7.11-29-x86_64.pkg.tar.zst: usr/share/haskell/register/dhall-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dhall-json
version:              1.7.11
visibility:           public
id:                   dhall-json-1.7.11-1ZPO1L0wa7GBkZfyJkKE1a
key:                  dhall-json-1.7.11-1ZPO1L0wa7GBkZfyJkKE1a
license:              BSD-3-Clause
copyright:            2017 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Convert between Dhall and JSON or YAML
description:
    Use this package if you want to convert between Dhall expressions and JSON
    or YAML. You can use this package as a library or an executable:

    * See the "Dhall.JSON" or "Dhall.JSONToDhall" modules if you want to use
    this package as a library

    * Use the @dhall-to-json@, @dhall-to-yaml@, or @json-to-dhall@ programs from
    this package if you want an executable

    The "Dhall.JSON" and "Dhall.JSONToDhall" modules also contains instructions
    for how to use this package

category:             Compiler
abi:                  4efa567e9bfb40ef894cd09c5f341b3e
exposed:              True
exposed-modules:
    Dhall.DhallToYaml.Main Dhall.JSON Dhall.JSON.Yaml Dhall.JSONToDhall

hidden-modules:       Dhall.JSON.Compat Dhall.JSON.Util
import-dirs:          /usr/lib/ghc-9.0.2/site-local/dhall-json-1.7.11
library-dirs:         /usr/lib/ghc-9.0.2/site-local/dhall-json-1.7.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-json
hs-libraries:         HSdhall-json-1.7.11-1ZPO1L0wa7GBkZfyJkKE1a
depends:
    aeson-2.1.1.0-6f0SUJ6dh2u49Oyg8vjVqb
    aeson-pretty-0.8.9-BR2EtrjNJL1AKZdgTeGPcT
    aeson-yaml-1.1.0.1-zKAbfk3rMDIppN40wUxV3 base-4.15.1.0
    bytestring-0.10.12.1 containers-0.6.4.1
    dhall-1.41.2-8LmCPFQ8Q5yJY3cjzmVC59 exceptions-0.10.4
    filepath-1.4.2.1 lens-family-core-2.1.2-JgL24qTIUymKZLaMFOVhTK
    optparse-applicative-0.17.0.0-G97y0UrNgMFEGAnnF72sOS
    prettyprinter-1.7.1-H3TJ5QGUcvJFh5pZ09MyFu
    scientific-0.3.7.0-994Cd8S1bkZ9FDNHRggxUL text-1.2.5.0
    unordered-containers-0.2.19.1-8VYAOBvAPnuAGZDvxcTgvW
    vector-0.13.0.0-C4IY0qsV06C5Tx1gtETdzw

haddock-interfaces:   /usr/share/doc/dhall-json/html/dhall-json.haddock
haddock-html:         /usr/share/doc/dhall-json/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> dhall-json-1.7.11-35-x86_64.pkg.tar.zst: usr/share/haskell/register/dhall-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dhall-json
version:              1.7.11
visibility:           public
id:                   dhall-json-1.7.11-Gr4R8VKOw7S8rV4r2Knp4L
key:                  dhall-json-1.7.11-Gr4R8VKOw7S8rV4r2Knp4L
license:              BSD-3-Clause
copyright:            2017 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Convert between Dhall and JSON or YAML
description:
    Use this package if you want to convert between Dhall expressions and JSON
    or YAML. You can use this package as a library or an executable:

    * See the "Dhall.JSON" or "Dhall.JSONToDhall" modules if you want to use
    this package as a library

    * Use the @dhall-to-json@, @dhall-to-yaml@, or @json-to-dhall@ programs from
    this package if you want an executable

    The "Dhall.JSON" and "Dhall.JSONToDhall" modules also contains instructions
    for how to use this package

category:             Compiler
abi:                  4b83d72de38c3dc29af29c5902af48be
exposed:              True
exposed-modules:
    Dhall.DhallToYaml.Main Dhall.JSON Dhall.JSON.Yaml Dhall.JSONToDhall

hidden-modules:       Dhall.JSON.Compat Dhall.JSON.Util
import-dirs:          /usr/lib/ghc-9.0.2/site-local/dhall-json-1.7.11
library-dirs:         /usr/lib/ghc-9.0.2/site-local/dhall-json-1.7.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-json
hs-libraries:         HSdhall-json-1.7.11-Gr4R8VKOw7S8rV4r2Knp4L
depends:
    aeson-2.1.1.0-8KPen6hyeogLmhemp4ZbOa
    aeson-pretty-0.8.9-HgDgW0QkNCrJG86cGxB5yu
    aeson-yaml-1.1.0.1-70ogxBkR57ZIM0Zx5sWqj1 base-4.15.1.0
    bytestring-0.10.12.1 containers-0.6.4.1
    dhall-1.41.2-5DWJo09SAu99ofZCWiUWtP exceptions-0.10.4
    filepath-1.4.2.1 lens-family-core-2.1.2-JgL24qTIUymKZLaMFOVhTK
    optparse-applicative-0.17.0.0-8lW6r0BM3spDpBWlvE7jOi
    prettyprinter-1.7.1-1eigGMPeiKS44iOuiueNMF
    scientific-0.3.7.0-4jDy2Qi3SPf6ae03s0nfwm text-1.2.5.0
    unordered-containers-0.2.19.1-AupS6pw9cGS61feF3nE08
    vector-0.13.0.0-FO1psvzIWe996069p2V3EL

haddock-interfaces:   /usr/share/doc/dhall-json/html/dhall-json.haddock
haddock-html:         /usr/share/doc/dhall-json/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
